% AXISANGLE2R
% Converts from axis angle to rotation matrix.
%
%% Description
%
% Author -
%         Ernesto Homar Teniente Aviles
%         CONACYT Scholarship
%         Institut de Robotica i Informatica Industrial, CSIC-UPC
%         Last change: 09/2010
% 
% Usage:
%   R = axisAngle2R(axis_angle)
%
% Variables
%
% Inputs :
%   rotVec  - a 4x1 vector, axis angle vector [theta n_x n_y n_z]
% 
% Outputs :
%   R       - a 3x3 matrix,rotation matrix
% 

%% Code :
function  R = axisAngle2R(axis_angle)

theta = axis_angle(1);
wx = axis_angle(2);
wy = axis_angle(3);
wz = axis_angle(4);
cos_th= cos(theta);
sin_th = sin(theta);
v_th = 1-cos_th;

R= [(wx^2*v_th + cos_th) (wx*wy*v_th-wz*sin_th) (wx*wz*v_th+wy*sin_th)
    (wx*wy*v_th+wz*sin_th) (wy^2*v_th + cos_th) (wy*wz*v_th-wx*sin_th)
    (wx*wz*v_th-wy*sin_th) (wy*wz*v_th+wx*sin_th) (wz^2*v_th + cos_th)];
