%% PARSEHOKUYO3DONESCAN -
%
%
%
%% Description-
%
% Author - 	
%           Ernesto Homar Teniente Aviles
% 			CONACYT Scholarship
%			Institut de Robotica i Informatica Industrial, CSIC-UPC
% Last change -
%           MAR, 2010 
%
% This code has been developed as part of 
% 
% Usage:
%    scan = parseHokuyo3DOneScan(file{,OPTIONS])
%
% Input:
%
%
%   Options:
%     'OutType' - 1, struct('points', 'intesity','ts','device'),DEFAULT
%                 2, struct('points', 'x','y','z','ts','device')
%     'OnlyTimeStamps' - a bool, 0 DEFAULT.
%     'OnlyPoints'     - a bool, 0 DEFAULT.
%     'NoIntesity'     - a bool, 0 DEFAULT means intesity will be imported
% 
% Output:
%   scan - struct according with 'OutType'
%     NOTE: 'ts' - struct('ini.sec','ini.nsec','end.sec','end.nsec')
%                 ini  - initial scan time
%                 end  - ending  scan time
%                 sec  - seconds
%                 nsec - nanoseconds

%% CODE-
function scan = parseHokuyo3DOneScan(file,varargin)

chkvarargin(varargin,2);

[out_type ,   ...
 only_ts ,    ...
 only_points, ...
 no_intesity]= process_options(varargin,  ...
                      'OutType', 1,       ...
                      'OnlyTimeStamps',0, ...
                      'OnlyPoints',0,     ...
                      'NoIntesity',0);

                    

fid = importdata(file,'\t',2);

if ~only_ts
  switch out_type
    case 1
      scan.points = [ fid.data(:,1)';
                      fid.data(:,2)';
                      fid.data(:,3)']/1000;
    case 2
      scan.x = (fid.data(:,1)/1000)';
      scan.y = (fid.data(:,2)/1000)';
      scan.z = (fid.data(:,3)/1000)';

    otherwise
          error('Invalid argument for out_type!')
          
  end
  if ~no_intesity
    datasz = size(fid.data,2);
    if datasz ==4
      scan.intesity =fid.data(:,4)';
    end
  end
end



if ~only_points
tmp = textscan(fid.textdata{1,:},'%s %s %d %d',1);
scan.ts.ini.sec = tmp{3};
scan.ts.ini.nsec = tmp{4};
tmp = textscan(fid.textdata{2,:},'%s %s %d %d',1);
scan.ts.end.sec = tmp{3};
scan.ts.end.nsec = tmp{4};
scan.device = 'laser3d';
end

