% PARSEHOKUYO3DSCANS
%
%% Description:
%
% Author - 	Ernesto Homar Teniente Avilés
%           CONACYT Scholars
%           Institut de Robotica i Informatica Industrial, CSIC-UPC
%           Last change:
%               Date: 17/11/2010
%               Author: Author
%			          Version 1.3
% This code has been developed as part of the XXXX Project
% XXX-YYY-000000
%
% Usage:
%		scans = parseHokuyo3DScans(files[,OPTIONS])
%
% Inputs:
%     argin - a nxm matrix, data to use
%
%   Options:
%     'OutType'   - 1, struct('points', 'intesity','ts','device'),DEFAULT
%                   2, struct('points', 'x','y','z','ts','device')
%     'FirstScan' - integer
%			'LastScan'  - integer
%     'OnlyTimeStamps' - a bool, 0 DEFAULT.
%     'OnlyPoints'     - a bool, 0 DEFAULT.
%     'NoIntesity'     - a bool, 0 DEFAULT means intesity will be imported
%
% Outputs:
%   scans - struct according with 'OutType', with size ini-last+1
%
%% CODE




function scans = parseHokuyo3DScans(files,varargin)


chkvarargin(varargin,2)

n_files = size(files,2);



[out_type,    ...
 ini,         ...
 last,        ...
 only_ts ,    ...
 only_points, ...
 no_intesity] = process_options(            ...
                      varargin,             ...
                      'OutType', 1,         ...
                      'FirstScan', 1,       ...
			                'LastScan',  n_files, ...
                      'OnlyTimeStamps',0,   ...
                      'OnlyPoints',0,       ...
                      'NoIntesity',O);


fprintf('Parsing laser txt files ...')
if last > n_scans
  warnig(fprintf('Invalid last scan!!! Last scan is: %d',n_scans))
end

cell_col= last-ini+1;
alloc = cell(1,cell_col);
switch out_type
    case 2
        scans = struct(         ...
            'x', alloc,         ...
            'y', alloc,         ...
            'z', alloc,         ...
            'intesity', alloc,  ...
            'ts', alloc,        ...
            'device',alloc); 
    case 1
        scans = struct(         ...
            'points', alloc,      ...
            'intesity', alloc,  ...
            'ts', alloc,       ...
            'device',alloc);
        
    otherwise
        errosr('Invalid argument for out_type!')
end

for i=ini:last
   scans(i) = parseHokuyo3DOneScan(files(i).File, ...
                      'OutType', out_type,        ...
                      'OnlyTimeStamps', only_ts,  ...
                      'OnlyPoints', only_points,  ...
                      'NoIntesity',no_intesity); 
    fprintf('.')
end
fprintf('DONE\n')